@@ -4,6 +4,8 @@ import textwrap
 
 subcommands = [
     ("serve", "taskqtool.cli.serve"),
+    ("task", "taskqtool.cli.task"),
+    ("show","taskqtool.cli.show")
 ]
 
 
