@@ -28,7 +28,7 @@ class CLICommand:
             "scriptPath": scriptPath.__str__(),
             "shell": shell,
             "submitTime": submitTime,
-            "pid": pid.hex,
+            "pid": pid.int,
             "running": running
         }])
         pprint(res)
